MATH-1443: Depend on "Commons Statistics".

Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/4ce6378e
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/4ce6378e
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/4ce6378e

Branch: refs/heads/master
Commit: 4ce6378eb6024e33a86fb76e25086621971da586
Parents: 8dba68a
Author: Gilles <[email protected]>
Authored: Wed Jan 24 17:10:12 2018 +0100
Committer: Gilles <[email protected]>
Committed: Wed Jan 24 17:10:12 2018 +0100

----------------------------------------------------------------------
 .../apache/commons/math4/stat/inference/BinomialTest.java |  2 +-
 .../commons/math4/stat/inference/ChiSquareTest.java       |  2 +-
 .../org/apache/commons/math4/stat/inference/GTest.java    |  2 +-
 .../commons/math4/stat/inference/MannWhitneyUTest.java    |  2 +-
 .../apache/commons/math4/stat/inference/OneWayAnova.java  | 10 +++++-----
 .../org/apache/commons/math4/stat/inference/TTest.java    |  4 ++--
 .../math4/stat/inference/WilcoxonSignedRankTest.java      |  2 +-
 7 files changed, 12 insertions(+), 12 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/BinomialTest.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/stat/inference/BinomialTest.java 
b/src/main/java/org/apache/commons/math4/stat/inference/BinomialTest.java
index 4a94130..7b773c6 100644
--- a/src/main/java/org/apache/commons/math4/stat/inference/BinomialTest.java
+++ b/src/main/java/org/apache/commons/math4/stat/inference/BinomialTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.BinomialDistribution;
+import org.apache.commons.statistics.distribution.BinomialDistribution;
 import org.apache.commons.math4.exception.MathIllegalArgumentException;
 import org.apache.commons.math4.exception.MathInternalError;
 import org.apache.commons.math4.exception.NotPositiveException;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/ChiSquareTest.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/stat/inference/ChiSquareTest.java 
b/src/main/java/org/apache/commons/math4/stat/inference/ChiSquareTest.java
index 8b67a33..d8649d1 100644
--- a/src/main/java/org/apache/commons/math4/stat/inference/ChiSquareTest.java
+++ b/src/main/java/org/apache/commons/math4/stat/inference/ChiSquareTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.ChiSquaredDistribution;
+import org.apache.commons.statistics.distribution.ChiSquaredDistribution;
 import org.apache.commons.math4.exception.DimensionMismatchException;
 import org.apache.commons.math4.exception.MaxCountExceededException;
 import org.apache.commons.math4.exception.NotPositiveException;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/GTest.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/inference/GTest.java 
b/src/main/java/org/apache/commons/math4/stat/inference/GTest.java
index 0da2043..57d5595 100644
--- a/src/main/java/org/apache/commons/math4/stat/inference/GTest.java
+++ b/src/main/java/org/apache/commons/math4/stat/inference/GTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.ChiSquaredDistribution;
+import org.apache.commons.statistics.distribution.ChiSquaredDistribution;
 import org.apache.commons.math4.exception.DimensionMismatchException;
 import org.apache.commons.math4.exception.MaxCountExceededException;
 import org.apache.commons.math4.exception.NotPositiveException;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/MannWhitneyUTest.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/inference/TTest.java 
b/src/main/java/org/apache/commons/math4/stat/inference/TTest.java
index 45bb9f3..27783d2 100644
--- a/src/main/java/org/apache/commons/math4/stat/inference/TTest.java
+++ b/src/main/java/org/apache/commons/math4/stat/inference/TTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.TDistribution;
+import org.apache.commons.statistics.distribution.TDistribution;
 import org.apache.commons.math4.exception.DimensionMismatchException;
 import org.apache.commons.math4.exception.MathIllegalArgumentException;
 import org.apache.commons.math4.exception.MaxCountExceededException;
@@ -51,7 +51,7 @@ import org.apache.commons.math4.util.FastMath;
  * <p>
  * Input to tests can be either <code>double[]</code> arrays or
  * {@link StatisticalSummary} instances.</p><p>
- * Uses commons-math {@link 
org.apache.commons.math4.distribution.TDistribution}
+ * Uses commons-math {@link 
org.apache.commons.statistics.distribution.TDistribution}
  * implementation to estimate exact p-values.</p>
  *
  */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/WilcoxonSignedRankTest.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/stat/inference/MannWhitneyUTest.java 
b/src/main/java/org/apache/commons/math4/stat/inference/MannWhitneyUTest.java
index f938c17..abe4183 100644
--- 
a/src/main/java/org/apache/commons/math4/stat/inference/MannWhitneyUTest.java
+++ 
b/src/main/java/org/apache/commons/math4/stat/inference/MannWhitneyUTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.statistics.distribution.NormalDistribution;
 import org.apache.commons.math4.exception.ConvergenceException;
 import org.apache.commons.math4.exception.MaxCountExceededException;
 import org.apache.commons.math4.exception.NoDataException;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/OneWayAnova.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/stat/inference/OneWayAnova.java 
b/src/main/java/org/apache/commons/math4/stat/inference/OneWayAnova.java
index e54daf1..c50fba0 100644
--- a/src/main/java/org/apache/commons/math4/stat/inference/OneWayAnova.java
+++ b/src/main/java/org/apache/commons/math4/stat/inference/OneWayAnova.java
@@ -19,7 +19,7 @@ package org.apache.commons.math4.stat.inference;
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.commons.math4.distribution.FDistribution;
+import org.apache.commons.statistics.distribution.FDistribution;
 import org.apache.commons.math4.exception.ConvergenceException;
 import org.apache.commons.math4.exception.DimensionMismatchException;
 import org.apache.commons.math4.exception.MaxCountExceededException;
@@ -37,7 +37,7 @@ import org.apache.commons.math4.util.MathUtils;
  * computer programmers).  When two categories are given, this is equivalent to
  * the {@link org.apache.commons.math4.stat.inference.TTest}.
  * </p><p>
  * Uses the {@link org.apache.commons.math4.distribution.FDistribution
  * commons-math F Distribution implementation} to estimate exact p-values.</p>
  * <p>This implementation is based on a description at
  * http://faculty.vassar.edu/lowry/ch13pt1.html</p>
@@ -103,7 +103,7 @@ public class OneWayAnova {
      * <code>categoryData</code> collection and each of these arrays must
      * contain at least two values.</li></ul><p>
      * This implementation uses the
-     * {@link org.apache.commons.math4.distribution.FDistribution
+     * {@link org.apache.commons.statistics.distribution.FDistribution
      * commons-math F Distribution implementation} to estimate the exact
      * p-value, using the formula<pre>
      *   p = 1 - cumulativeProbability(F)</pre>
@@ -142,7 +142,7 @@ public class OneWayAnova {
      * <code>categoryData</code> collection and each of these statistics must
      * contain at least two values.</li></ul><p>
      * This implementation uses the
-     * {@link org.apache.commons.math4.distribution.FDistribution
+     * {@link org.apache.commons.statistics.distribution.FDistribution
      * commons-math F Distribution implementation} to estimate the exact
      * p-value, using the formula<pre>
      *   p = 1 - cumulativeProbability(F)</pre>
@@ -223,7 +223,7 @@ public class OneWayAnova {
      * <li>alpha must be strictly greater than 0 and less than or equal to 0.5.
      * </li></ul><p>
      * This implementation uses the
-     * {@link org.apache.commons.math4.distribution.FDistribution
+     * {@link org.apache.commons.statistics.distribution.FDistribution
      * commons-math F Distribution implementation} to estimate the exact
      * p-value, using the formula<pre>
      *   p = 1 - cumulativeProbability(F)</pre>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/4ce6378e/src/main/java/org/apache/commons/math4/stat/inference/TTest.java
----------------------------------------------------------------------
@@ -37,7 +37,7 @@ import org.apache.commons.math4.util.MathUtils;
  * the {@link org.apache.commons.math4.stat.inference.TTest}.
  * </p><p>
- * Uses the {@link org.apache.commons.math4.distribution.FDistribution
+ * Uses the {@link org.apache.commons.statistics.distribution.FDistribution
  * commons-math F Distribution implementation} to estimate exact p-values.</p>
  * <p>This implementation is based on a description at
diff --git 
a/src/main/java/org/apache/commons/math4/stat/inference/WilcoxonSignedRankTest.java
 
b/src/main/java/org/apache/commons/math4/stat/inference/WilcoxonSignedRankTest.java
index 4ffff61..efa9ca5 100644
--- 
a/src/main/java/org/apache/commons/math4/stat/inference/WilcoxonSignedRankTest.java
+++ 
b/src/main/java/org/apache/commons/math4/stat/inference/WilcoxonSignedRankTest.java
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math4.stat.inference;
 
-import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.statistics.distribution.NormalDistribution;
 import org.apache.commons.math4.exception.ConvergenceException;
 import org.apache.commons.math4.exception.DimensionMismatchException;
 import org.apache.commons.math4.exception.MaxCountExceededException;

Reply via email to